@@ -1,5 +1,5 @@
 package MooX::Role::Pluggable;
-$MooX::Role::Pluggable::VERSION = '1.002001';
+$MooX::Role::Pluggable::VERSION = '1.002002';
 use Carp;
 use strictures 2;
 
@@ -111,9 +111,8 @@ sub _pluggable_process {
   #   - Conditionals have been optimized a bit.
   #
   # I'm open to other ideas . . .
-  unless (ref $args) {
-    confess 'Expected a type, event, and (possibly empty) args ARRAY'
-  }
+  confess 'Expected a type, event, and (possibly empty) args ARRAY'
+    unless ref $args;
 
   my $prefix = $self->__pluggable_opts->{ev_prefix};
   substr($event, 0, length($prefix), '') if index($event, $prefix) == 0;
@@ -121,19 +120,14 @@ sub _pluggable_process {
   my $meth = $self->__pluggable_opts->{types}->{$type} .'_'. $event;
 
   my ($retval, $self_ret, @extra) = EAT_NONE;
-
   local $@;
   if      ( $self->can($meth) ) {
     # Dispatch to ourself
-    eval {;
-      $self_ret = $self->$meth($self, \(@$args), \@extra)
-    };
+    eval {; $self_ret = $self->$meth($self, \(@$args), \@extra) };
     __plugin_process_chk($self, $self, $meth, $self_ret);
   } elsif ( $self->can('_default') ) {
     # Dispatch to _default
-    eval {;
-      $self_ret = $self->_default($self, $meth, \(@$args), \@extra)
-    };
+    eval {; $self_ret = $self->_default($self, $meth, \(@$args), \@extra) };
     __plugin_process_chk($self, $self, '_default', $self_ret);
   }
 
@@ -150,9 +144,7 @@ sub _pluggable_process {
     return EAT_ALL
   }
 
-  if (@extra) {
-    push @$args, splice @extra, 0, scalar(@extra)
-  }
+  push @$args, splice @extra, 0, scalar(@extra) if @extra;
 
   my $handle_ref = $self->__pluggable_loaded->{HANDLE};
   my $plug_ret;
@@ -750,7 +742,7 @@ unless caller;
 
 =head1 NAME
 
-MooX::Role::Pluggable - Add a plugin pipeline to your cows
+MooX::Role::Pluggable - A plugin pipeline for your Moo-based class
 
 =head1 SYNOPSIS
 
@@ -878,9 +870,7 @@ MooX::Role::Pluggable - Add a plugin pipeline to your cows
 
   sub BUILD {
     my ($self) = @_;
-    $self->dispatcher->plugin_add( 'MyPlugin',
-      MyPlugin->new()
-    );
+    $self->dispatcher->plugin_add( 'MyPlugin', MyPlugin->new );
   }
 
   sub do_stuff {
@@ -968,13 +958,14 @@ Shuts down the plugin pipeline, unregistering/unloading all known plugins.
   }
 
 C<_pluggable_event> is called for internal notifications, such as plugin
-load/unload and error reporting (see L</Internal Events>) -- it should be
+load/unload and error reporting (see L</Internal Events>) -- it can be
 overriden in your consuming class to do something useful with the dispatched
 event and any arguments passed.
 
 The C<$event> given will be prefixed with the configured B<event_prefix>.
 
-Also see L</Internal Events>.
+(It's not strictly necessary to implement a C<_pluggable_event> handler; errors
+will also C<warn>.)
 
 =head2 Registration
 
